@@ -5,8 +5,8 @@ The pngme.api package exposes utilities to interact with Pngme's financial data.
 
 from .client import AsyncClient, Client
 from .core import with_concurrency_limit
-from .resources.accounts import Account
 from .resources.alerts import Alert
 from .resources.balances import BalanceRecord
 from .resources.credit_report import CreditReport
+from .resources.institutions import Institution
 from .resources.transactions import TransactionRecord
