@@ -7,7 +7,7 @@ from pydantic import BaseModel
 from ..core import BaseClient, with_concurrency_limit
 from ..encoders import encode_query_params
 
-PATH = "/users/{user_uuid}/accounts/{account_uuid}/alerts"
+PATH = "/users/{user_uuid}/institutions/{institution_id}/alerts"
 
 
 class Alert(BaseModel):
@@ -21,7 +21,7 @@ class AlertsMeta(BaseModel):
     page: int
     utc_starttime: Optional[datetime] = None
     utc_endtime: Optional[datetime] = None
-    acct_uuid: str
+    institution_id: str
     user_uuid: str
     total_alerts_count: int
     max_pages: int
@@ -43,7 +43,7 @@ class BaseAlertsResource:
     async def _get_page(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -51,7 +51,7 @@ class BaseAlertsResource:
     ) -> AlertsResponse:
         async with self._client.session() as session:
             response = await session.get(
-                PATH.format(user_uuid=user_uuid, account_uuid=account_uuid),
+                PATH.format(user_uuid=user_uuid, institution_id=institution_id),
                 params=encode_query_params(
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
@@ -66,14 +66,14 @@ class BaseAlertsResource:
     async def _get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[Alert]:
         response = await self._get_page(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -83,7 +83,7 @@ class BaseAlertsResource:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
-                    account_uuid=account_uuid,
+                    institution_id=institution_id,
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
@@ -105,14 +105,14 @@ class AsyncAlertsResource(BaseAlertsResource):
     async def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[Alert]:
         return await self._get(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -123,7 +123,7 @@ class SyncAlertsResource(BaseAlertsResource):
     def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -131,7 +131,7 @@ class SyncAlertsResource(BaseAlertsResource):
         return asyncio.run(
             self._get(
                 user_uuid=user_uuid,
-                account_uuid=account_uuid,
+                institution_id=institution_id,
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
