@@ -8,7 +8,7 @@ from ..core import BaseClient, with_concurrency_limit
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency
 
-PATH = "/users/{user_uuid}/accounts/{account_uuid}/balances"
+PATH = "/users/{user_uuid}/institutions/{institution_id}/balances"
 
 
 class BalanceRecord(BaseModel):
@@ -24,7 +24,7 @@ class BalancesMeta(BaseModel):
     page: int
     utc_starttime: Optional[datetime] = None
     utc_endtime: Optional[datetime] = None
-    acct_uuid: str
+    institution_id: str
     user_uuid: str
     total_balances_count: int
     max_pages: int
@@ -52,7 +52,7 @@ class BaseBalancesResource:
     async def _get_page(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -60,7 +60,7 @@ class BaseBalancesResource:
     ) -> BalancesResponse:
         async with self._client.session() as session:
             response = await session.get(
-                PATH.format(user_uuid=user_uuid, account_uuid=account_uuid),
+                PATH.format(user_uuid=user_uuid, institution_id=institution_id),
                 params=encode_query_params(
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
@@ -75,14 +75,14 @@ class BaseBalancesResource:
     async def _get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -92,7 +92,7 @@ class BaseBalancesResource:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
-                    account_uuid=account_uuid,
+                    institution_id=institution_id,
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
@@ -119,14 +119,14 @@ class AsyncBalancesResource(BaseBalancesResource):
     async def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
         return await self._get(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -137,7 +137,7 @@ class SyncBalancesResource(BaseBalancesResource):
     def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -145,7 +145,7 @@ class SyncBalancesResource(BaseBalancesResource):
         return asyncio.run(
             self._get(
                 user_uuid=user_uuid,
-                account_uuid=account_uuid,
+                institution_id=institution_id,
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
