@@ -8,7 +8,7 @@ from ..core import BaseClient, with_concurrency_limit
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency, Impact
 
-PATH = "/users/{user_uuid}/accounts/{account_uuid}/transactions"
+PATH = "/users/{user_uuid}/institutions/{institution_id}/transactions"
 
 
 class TransactionRecord(BaseModel):
@@ -26,7 +26,7 @@ class TransactionsMeta(BaseModel):
     page: int
     utc_starttime: Optional[datetime] = None
     utc_endtime: Optional[datetime] = None
-    acct_uuid: str
+    institution_id: str
     user_uuid: str
     total_transactions_count: int
     max_pages: int
@@ -54,7 +54,7 @@ class BaseTransactionsResource:
     async def _get_page(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -62,7 +62,7 @@ class BaseTransactionsResource:
     ) -> TransactionsResponse:
         async with self._client.session() as session:
             response = await session.get(
-                PATH.format(user_uuid=user_uuid, account_uuid=account_uuid),
+                PATH.format(user_uuid=user_uuid, institution_id=institution_id),
                 params=encode_query_params(
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
@@ -77,14 +77,14 @@ class BaseTransactionsResource:
     async def _get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[TransactionRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -94,7 +94,7 @@ class BaseTransactionsResource:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
-                    account_uuid=account_uuid,
+                    institution_id=institution_id,
                     utc_starttime=utc_starttime,
                     utc_endtime=utc_endtime,
                     labels=labels,
@@ -121,14 +121,14 @@ class AsyncTransactionsResource(BaseTransactionsResource):
     async def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> List[TransactionRecord]:
         return await self._get(
             user_uuid=user_uuid,
-            account_uuid=account_uuid,
+            institution_id=institution_id,
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
@@ -139,7 +139,7 @@ class SyncTransactionsResource(BaseTransactionsResource):
     def get(
         self,
         user_uuid: str,
-        account_uuid: str,
+        institution_id: str,
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
@@ -147,7 +147,7 @@ class SyncTransactionsResource(BaseTransactionsResource):
         return asyncio.run(
             self._get(
                 user_uuid=user_uuid,
-                account_uuid=account_uuid,
+                institution_id=institution_id,
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
